=== modified file 'drizzled/log_event.cc'
--- drizzled/log_event.cc	2008-09-23 00:09:32 +0000
+++ drizzled/log_event.cc	2008-09-23 00:10:39 +0000
@@ -2179,9 +2179,9 @@
     thd->set_time((time_t)when);
     thd->query_length= q_len_arg;
     thd->query= (char*)query_arg;
-    VOID(pthread_mutex_lock(&LOCK_thread_count));
+    pthread_mutex_lock(&LOCK_thread_count);
     thd->query_id = next_query_id();
-    VOID(pthread_mutex_unlock(&LOCK_thread_count));
+    pthread_mutex_unlock(&LOCK_thread_count);
     thd->variables.pseudo_thread_id= thread_id;		// for temp tables
 
     if (ignored_error_code((expected_error= error_code)) ||
@@ -2364,7 +2364,7 @@
   } /* End of if (db_ok(... */
 
 end:
-  VOID(pthread_mutex_lock(&LOCK_thread_count));
+  pthread_mutex_lock(&LOCK_thread_count);
   /*
     Probably we have set thd->query, thd->db, thd->catalog to point to places
     in the data_buf of this event. Now the event is going to be deleted
@@ -2379,7 +2379,7 @@
   thd->set_db(NULL, 0);                 /* will free the current database */
   thd->query= 0;			// just to be sure
   thd->query_length= 0;
-  VOID(pthread_mutex_unlock(&LOCK_thread_count));
+  pthread_mutex_unlock(&LOCK_thread_count);
   close_thread_tables(thd);      
   /*
     As a disk space optimization, future masters will not log an event for
@@ -3562,9 +3562,9 @@
   if (rpl_filter->db_ok(thd->db))
   {
     thd->set_time((time_t)when);
-    VOID(pthread_mutex_lock(&LOCK_thread_count));
+    pthread_mutex_lock(&LOCK_thread_count);
     thd->query_id = next_query_id();
-    VOID(pthread_mutex_unlock(&LOCK_thread_count));
+    pthread_mutex_unlock(&LOCK_thread_count);
     /*
       Initing thd->row_count is not necessary in theory as this variable has no
       influence in the case of the slave SQL thread (it is used to generate a
@@ -3718,12 +3718,12 @@
 error:
   thd->net.vio = 0; 
   const char *remember_db= thd->db;
-  VOID(pthread_mutex_lock(&LOCK_thread_count));
+  pthread_mutex_lock(&LOCK_thread_count);
   thd->catalog= 0;
   thd->set_db(NULL, 0);                   /* will free the current database */
   thd->query= 0;
   thd->query_length= 0;
-  VOID(pthread_mutex_unlock(&LOCK_thread_count));
+  pthread_mutex_unlock(&LOCK_thread_count);
   close_thread_tables(thd);
 
   if (thd->is_slave_error)

=== modified file 'drizzled/sj_tmp_table.cc'
--- drizzled/sj_tmp_table.cc	2008-09-22 23:53:43 +0000
+++ drizzled/sj_tmp_table.cc	2008-09-23 00:10:39 +0000
@@ -1,3 +1,22 @@
+/* - mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
 #include "sj_tmp_table.h"
 
 /*
@@ -5,43 +24,43 @@
 
   SYNOPSIS
 
-    create_duplicate_weedout_tmp_table()
-      thd
-      uniq_tuple_length_arg
-      SJ_TMP_TABLE 
+  create_duplicate_weedout_tmp_table()
+  thd
+  uniq_tuple_length_arg
+  SJ_TMP_TABLE
 
   DESCRIPTION
-    Create a temporary table to weed out duplicate rowid combinations. The
-    table has a single column that is a concatenation of all rowids in the
-    combination. 
-
-    Depending on the needed length, there are two cases:
-
-    1. When the length of the column < max_key_length:
-
-      CREATE TABLE tmp (col VARBINARY(n) NOT NULL, UNIQUE KEY(col));
-
-    2. Otherwise (not a valid SQL syntax but internally supported):
-
-      CREATE TABLE tmp (col VARBINARY NOT NULL, UNIQUE CONSTRAINT(col));
-
-    The code in this function was produced by extraction of relevant parts
-    from create_tmp_table().
+  Create a temporary table to weed out duplicate rowid combinations. The
+  table has a single column that is a concatenation of all rowids in the
+  combination.
+
+  Depending on the needed length, there are two cases:
+
+  1. When the length of the column < max_key_length:
+
+  CREATE TABLE tmp (col VARBINARY(n) NOT NULL, UNIQUE KEY(col));
+
+  2. Otherwise (not a valid SQL syntax but internally supported):
+
+  CREATE TABLE tmp (col VARBINARY NOT NULL, UNIQUE CONSTRAINT(col));
+
+  The code in this function was produced by extraction of relevant parts
+  from create_tmp_table().
 
   RETURN
-    created table
-    NULL on error
+  created table
+  NULL on error
 */
 
-Table *create_duplicate_weedout_tmp_table(THD *thd, 
-					  uint uniq_tuple_length_arg,
-					  SJ_TMP_TABLE *sjtbl)
+Table *create_duplicate_weedout_tmp_table(THD *thd,
+                                          uint uniq_tuple_length_arg,
+                                          SJ_TMP_TABLE *sjtbl)
 {
   MEM_ROOT *mem_root_save, own_root;
   Table *table;
   TABLE_SHARE *share;
   uint  temp_pool_slot=MY_BIT_NONE;
-  char	*tmpname,path[FN_REFLEN];
+  char  *tmpname,path[FN_REFLEN];
   Field **reg_field;
   KEY_PART_INFO *key_part_info;
   KEY *keyinfo;
@@ -99,7 +118,7 @@
     return(NULL);
   }
   stpcpy(tmpname,path);
-  
+
 
   /* STEP 4: Create Table description */
   memset(table, 0, sizeof(*table));
@@ -111,7 +130,7 @@
 
   table->field=reg_field;
   table->alias= "weedout-tmp";
-  table->reginfo.lock_type=TL_WRITE;	/* Will be updated */
+  table->reginfo.lock_type=TL_WRITE;  /* Will be updated */
   table->db_stat=HA_OPEN_KEYFILE+HA_OPEN_RNDFILE;
   table->map=1;
   table->temp_pool_slot = temp_pool_slot;
@@ -151,9 +170,9 @@
     field->reset_fields();
     field->init(table);
     field->orig_table= NULL;
-     
+
     field->field_index= 0;
-    
+
     *(reg_field++)= field;
     *blob_field= 0;
     *reg_field= 0;
@@ -164,7 +183,7 @@
 
   uint reclength= field->pack_length();
   if (using_unique_constraint)
-  { 
+  {
     share->db_plugin= ha_lock_engine(0, myisam_hton);
     table->file= get_new_handler(share, &table->mem_root,
                                  share->db_type());
@@ -180,7 +199,7 @@
     goto err;
 
   null_count=1;
-  
+
   null_pack_length= 1;
   reclength += null_pack_length;
 
@@ -189,7 +208,7 @@
     uint alloc_length=ALIGN_SIZE(share->reclength + MI_UNIQUE_HASH_LENGTH+1);
     share->rec_buff_length= alloc_length;
     if (!(table->record[0]= (uchar*)
-                            alloc_root(&table->mem_root, alloc_length*3)))
+          alloc_root(&table->mem_root, alloc_length*3)))
       goto err;
     table->record[1]= table->record[0]+alloc_length;
     share->default_values= table->record[1]+alloc_length;
@@ -205,7 +224,7 @@
     recinfo->type=FIELD_NORMAL;
     recinfo->length=null_pack_length;
     recinfo++;
-    memset(null_flags, 255, null_pack_length);	// Set null fields
+    memset(null_flags, 255, null_pack_length);  // Set null fields
 
     table->null_flags= (uchar*) table->record[0];
     share->null_fields= null_count;
@@ -243,15 +262,15 @@
   //param->recinfo=recinfo;
   //store_record(table,s->default_values);        // Make empty default record
 
-  if (thd->variables.tmp_table_size == ~ (uint64_t) 0)		// No limit
+  if (thd->variables.tmp_table_size == ~ (uint64_t) 0)    // No limit
     share->max_rows= ~(ha_rows) 0;
   else
     share->max_rows= (ha_rows) (((share->db_type() == heap_hton) ?
                                  cmin(thd->variables.tmp_table_size,
-                                     thd->variables.max_heap_table_size) :
+                                      thd->variables.max_heap_table_size) :
                                  thd->variables.tmp_table_size) /
-			         share->reclength);
-  set_if_bigger(share->max_rows,1);		// For dummy start options
+                                share->reclength);
+  set_if_bigger(share->max_rows,1);    // For dummy start options
 
 
   //// keyinfo= param->keyinfo;
@@ -276,18 +295,18 @@
       key_part_info->key_type = FIELDFLAG_BINARY;
       if (!using_unique_constraint)
       {
-	if (!(key_field= field->new_key_field(thd->mem_root, table,
+        if (!(key_field= field->new_key_field(thd->mem_root, table,
                                               group_buff,
                                               field->null_ptr,
                                               field->null_bit)))
-	  goto err;
+          goto err;
         key_part_info->key_part_flag|= HA_END_SPACE_ARE_EQUAL; //todo need this?
       }
       keyinfo->key_length+=  key_part_info->length;
     }
   }
 
-  if (thd->is_fatal_error)				// If end of memory
+  if (thd->is_fatal_error)        // If end of memory
     goto err;
   share->db_record_offset= 1;
   if (share->db_type() == myisam_hton)
@@ -309,5 +328,5 @@
   table->free_tmp_table(thd);                    /* purecov: inspected */
   if (temp_pool_slot != MY_BIT_NONE)
     bitmap_lock_clear_bit(&temp_pool, temp_pool_slot);
-  return(NULL);				/* purecov: inspected */
+  return(NULL);        /* purecov: inspected */
 }

=== modified file 'drizzled/slave.cc'
--- drizzled/slave.cc	2008-09-22 23:53:43 +0000
+++ drizzled/slave.cc	2008-09-23 00:10:39 +0000
@@ -2178,10 +2178,10 @@
   sql_print_information(_("Slave I/O thread exiting, read up to log '%s', "
                           "position %s"),
                         IO_RPL_LOG_NAME, llstr(mi->master_log_pos,llbuff));
-  VOID(pthread_mutex_lock(&LOCK_thread_count));
+  pthread_mutex_lock(&LOCK_thread_count);
   thd->query = thd->db = 0; // extra safety
   thd->query_length= thd->db_length= 0;
-  VOID(pthread_mutex_unlock(&LOCK_thread_count));
+  pthread_mutex_unlock(&LOCK_thread_count);
   if (drizzle)
   {
     /*
@@ -2447,7 +2447,7 @@
     must "proactively" clear playgrounds:
   */
   rli->cleanup_context(thd, 1);
-  VOID(pthread_mutex_lock(&LOCK_thread_count));
+  pthread_mutex_lock(&LOCK_thread_count);
   /*
     Some extra safety, which should not been needed (normally, event deletion
     should already have done these assignments (each event which sets these
@@ -2455,7 +2455,7 @@
   */
   thd->query= thd->db= thd->catalog= 0;
   thd->query_length= thd->db_length= 0;
-  VOID(pthread_mutex_unlock(&LOCK_thread_count));
+  pthread_mutex_unlock(&LOCK_thread_count);
   thd_proc_info(thd, "Waiting for slave mutex on exit");
   pthread_mutex_lock(&rli->run_lock);
   /* We need data_lock, at least to wake up any waiting master_pos_wait() */

=== modified file 'drizzled/sql_show.cc'
--- drizzled/sql_show.cc	2008-09-22 23:53:43 +0000
+++ drizzled/sql_show.cc	2008-09-23 00:10:39 +0000
@@ -494,7 +494,7 @@
    it's a keyword
   */
 
-  VOID(packet->reserve(length*2 + 2));
+  packet->reserve(length*2 + 2);
   quote_char= (char) q;
   packet->append(&quote_char, 1, system_charset_info);
 
@@ -1117,7 +1117,7 @@
                             Protocol::SEND_NUM_ROWS | Protocol::SEND_EOF))
     return;
 
-  VOID(pthread_mutex_lock(&LOCK_thread_count)); // For unlink from list
+  pthread_mutex_lock(&LOCK_thread_count); // For unlink from list
   if (!thd->killed)
   {
     I_List_iterator<THD> it(threads);
@@ -1169,7 +1169,7 @@
       }
     }
   }
-  VOID(pthread_mutex_unlock(&LOCK_thread_count));
+  pthread_mutex_unlock(&LOCK_thread_count);
 
   thread_info *thd_info;
   time_t now= my_time(0);
@@ -1207,7 +1207,7 @@
 
   user= NullS;
 
-  VOID(pthread_mutex_lock(&LOCK_thread_count));
+  pthread_mutex_lock(&LOCK_thread_count);
 
   if (!thd->killed)
   {
@@ -1280,13 +1280,13 @@
 
       if (schema_table_store_record(thd, table))
       {
-        VOID(pthread_mutex_unlock(&LOCK_thread_count));
+        pthread_mutex_unlock(&LOCK_thread_count);
         return(1);
       }
     }
   }
 
-  VOID(pthread_mutex_unlock(&LOCK_thread_count));
+  pthread_mutex_unlock(&LOCK_thread_count);
   return(0);
 }
 
@@ -1628,7 +1628,7 @@
 {
 
   /* Ensure that thread id not killed during loop */
-  VOID(pthread_mutex_lock(&LOCK_thread_count)); // For unlink from list
+  pthread_mutex_lock(&LOCK_thread_count); // For unlink from list
 
   I_List_iterator<THD> it(threads);
   THD *tmp;
@@ -1640,7 +1640,7 @@
   while ((tmp= it++))
     add_to_status(to, &tmp->status_var);
   
-  VOID(pthread_mutex_unlock(&LOCK_thread_count));
+  pthread_mutex_unlock(&LOCK_thread_count);
   return;
 }
 

=== modified file 'drizzled/stacktrace.c'
--- drizzled/stacktrace.c	2008-09-22 23:53:43 +0000
+++ drizzled/stacktrace.c	2008-09-23 00:10:39 +0000
@@ -1,17 +1,21 @@
-/* Copyright (C) 2000 MySQL AB
-
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2008 Sun Microsystems, Inc.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
 
 /* Workaround for Bug#32082: VOID redefinition on Win results in compile errors*/
 #define DONT_DEFINE_VOID 1
@@ -60,45 +64,6 @@
 #define SIGRETURN_FRAME_OFFSET 23
 #endif
 
-#if defined(__alpha__) && defined(__GNUC__)
-/*
-  The only way to backtrace without a symbol table on alpha
-  is to find stq fp,N(sp), and the first byte
-  of the instruction opcode will give us the value of N. From this
-  we can find where the old value of fp is stored
-*/
-
-#define MAX_INSTR_IN_FUNC  10000
-
-inline uchar** find_prev_fp(uint32* pc, uchar** fp)
-{
-  int i;
-  for (i = 0; i < MAX_INSTR_IN_FUNC; ++i,--pc)
-  {
-    uchar* p = (uchar*)pc;
-    if (p[2] == 222 &&  p[3] == 35)
-    {
-      return (uchar**)((uchar*)fp - *(short int*)p);
-    }
-  }
-  return 0;
-}
-
-inline uint32* find_prev_pc(uint32* pc, uchar** fp)
-{
-  int i;
-  for (i = 0; i < MAX_INSTR_IN_FUNC; ++i,--pc)
-  {
-    char* p = (char*)pc;
-    if (p[1] == 0 && p[2] == 94 &&  p[3] == -73)
-    {
-      uint32* prev_pc = (uint32*)*((fp+p[0]/sizeof(fp)));
-      return prev_pc;
-    }
-  }
-  return 0;
-}
-#endif /* defined(__alpha__) && defined(__GNUC__) */
 
 #if BACKTRACE_DEMANGLE
 static void my_demangle_symbols(char **addrs, int n)
@@ -171,13 +136,13 @@
 
 #ifdef __i386__
   __asm __volatile__ ("movl %%ebp,%0"
-		      :"=r"(fp)
-		      :"r"(fp));
+                      :"=r"(fp)
+                      :"r"(fp));
 #endif
 #ifdef __x86_64__
   __asm __volatile__ ("movq %%rbp,%0"
-		      :"=r"(fp)
-		      :"r"(fp));
+                      :"=r"(fp)
+                      :"r"(fp));
 #endif
 #if defined(__alpha__) && defined(__GNUC__) 
   __asm __volatile__ ("mov $30,%0"
@@ -209,15 +174,6 @@
   }
 
   fprintf(stderr, "Stack range sanity check OK, backtrace follows:\n");
-#if defined(__alpha__) && defined(__GNUC__)
-  fprintf(stderr, "Warning: Alpha stacks are difficult -\
- will be taking some wild guesses, stack trace may be incorrect or \
- terminate abruptly\n");
-  /* On Alpha, we need to get pc */
-  __asm __volatile__ ("bsr %0, do_next; do_next: "
-		      :"=r"(pc)
-		      :"r"(pc));
-#endif  /* __alpha__ */
 
   /* We are 1 frame above signal frame with NPTL and 2 frames above with LT */
   sigreturn_frame_count = thd_lib_detected == THD_LIB_LT ? 2 : 1;
@@ -227,34 +183,9 @@
 #if defined(__i386__) || defined(__x86_64__)
     uchar** new_fp = (uchar**)*fp;
     fprintf(stderr, "%p\n", frame_count == sigreturn_frame_count ?
-	    *(fp + SIGRETURN_FRAME_OFFSET) : *(fp + 1));
+            *(fp + SIGRETURN_FRAME_OFFSET) : *(fp + 1));
 #endif /* defined(__386__)  || defined(__x86_64__) */
 
-#if defined(__alpha__) && defined(__GNUC__)
-    uchar** new_fp = find_prev_fp(pc, fp);
-    if (frame_count == sigreturn_frame_count - 1)
-    {
-      new_fp += 90;
-    }
-
-    if (fp && pc)
-    {
-      pc = find_prev_pc(pc, fp);
-      if (pc)
-	fprintf(stderr, "%p\n", pc);
-      else
-      {
-	fprintf(stderr, "Not smart enough to deal with the rest\
- of this stack\n");
-	goto end;
-      }
-    }
-    else
-    {
-      fprintf(stderr, "Not smart enough to deal with the rest of this stack\n");
-      goto end;
-    }
-#endif /* defined(__alpha__) && defined(__GNUC__) */
     if (new_fp <= fp )
     {
       fprintf(stderr, "New value of fp=%p failed sanity check,\

=== modified file 'drizzled/stacktrace.h'
--- drizzled/stacktrace.h	2008-09-16 00:00:48 +0000
+++ drizzled/stacktrace.h	2008-09-23 00:10:39 +0000
@@ -1,4 +1,4 @@
-/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+/* -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
  *  Copyright (C) 2008 Sun Microsystems
@@ -19,7 +19,7 @@
 
 #include "global.h"
 
-#ifdef	__cplusplus
+#ifdef __cplusplus
 extern "C" {
 #endif
 
@@ -28,31 +28,25 @@
 #endif
 
 #if BACKTRACE_DEMANGLE
-char *my_demangle(const char *mangled_name, int *status);
+  char *my_demangle(const char *mangled_name, int *status);
 #endif
 
-#ifdef TARGET_OS_LINUX
-#if defined(HAVE_STACKTRACE) || (defined (__x86_64__) || defined (__i386__) || (defined(__alpha__) && defined(__GNUC__)))
+#if defined(HAVE_STACKTRACE) || (defined (__x86_64__) || defined (__i386__) )
 #undef HAVE_STACKTRACE
 #define HAVE_STACKTRACE
 
-extern char* __bss_start;
-extern char* heap_start;
+  extern char* __bss_start;
+  extern char* heap_start;
 
 #define init_stacktrace() do {                                 \
-                            heap_start = (char*) &__bss_start; \
-                          } while(0);
-void check_thread_lib(void);
-#endif /* defined (__i386__) || (defined(__alpha__) && defined(__GNUC__))) */
-#elif defined (__WIN__)
-#define HAVE_STACKTRACE
-extern void set_exception_pointers(EXCEPTION_POINTERS *ep);
-#define init_stacktrace() {}
-#endif
+    heap_start = (char*) &__bss_start; \
+  } while(0);
+  void check_thread_lib(void);
+#endif /* defined (__i386__) */
 
 #ifdef HAVE_STACKTRACE
-void print_stacktrace(uchar* stack_bottom, ulong thread_stack);
-void safe_print_str(const char* name, const char* val, int max_len);
+  void print_stacktrace(uchar* stack_bottom, ulong thread_stack);
+  void safe_print_str(const char* name, const char* val, int max_len);
 #else
 /* Define empty prototypes for functions that are not implemented */
 #define init_stacktrace() {}
@@ -61,8 +55,8 @@
 #endif /* HAVE_STACKTRACE */
 
 
-void write_core(int sig);
+  void write_core(int sig);
 
-#ifdef	__cplusplus
+#ifdef  __cplusplus
 }
 #endif

=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2008-09-22 23:53:43 +0000
+++ drizzled/table.cc	2008-09-23 00:10:39 +0000
@@ -441,7 +441,7 @@
   error= 3;
   if (!(pos=get_form_pos(file,head,(TYPELIB*) 0)))
     goto err;                                   /* purecov: inspected */
-  VOID(my_seek(file,pos,MY_SEEK_SET,MYF(0)));
+  my_seek(file,pos,MY_SEEK_SET,MYF(0));
   if (my_read(file,forminfo,288,MYF(MY_NABP)))
     goto err;
 
@@ -503,7 +503,7 @@
 
   /* Read keyinformation */
   key_info_length= (uint) uint2korr(head+28);
-  VOID(my_seek(file,(ulong) uint2korr(head+6),MY_SEEK_SET,MYF(0)));
+  my_seek(file,(ulong) uint2korr(head+6),MY_SEEK_SET,MYF(0));
   if (read_string(file,(uchar**) &disk_buff,key_info_length))
     goto err;                                   /* purecov: inspected */
   if (disk_buff[0] & 0x80)
@@ -722,7 +722,7 @@
   if (pread(file, record, (size_t) share->reclength, record_offset) == 0)
     goto err;                                   /* purecov: inspected */
 
-  VOID(my_seek(file,pos+288,MY_SEEK_SET,MYF(0)));
+  my_seek(file,pos+288,MY_SEEK_SET,MYF(0));
 
   share->fields= uint2korr(forminfo+258);
   pos= uint2korr(forminfo+260);			/* Length of all screens */
@@ -1517,7 +1517,7 @@
   if (names)
   {
     length=uint2korr(head+4);
-    VOID(my_seek(file,64L,MY_SEEK_SET,MYF(0)));
+    my_seek(file,64L,MY_SEEK_SET,MYF(0));
     if (!(buf= (uchar*) my_malloc((size_t) length+a_length+names*4,
 				  MYF(MY_WME))) ||
 	my_read(file, buf+a_length, (size_t) (length+names*4),
@@ -1594,17 +1594,17 @@
 
     while (endpos > maxlength)
     {
-      VOID(my_seek(file,(ulong) (endpos-bufflength),MY_SEEK_SET,MYF(0)));
+      my_seek(file,(ulong) (endpos-bufflength),MY_SEEK_SET,MYF(0));
       if (my_read(file, buff, bufflength, MYF(MY_NABP+MY_WME)))
 	return(0L);
-      VOID(my_seek(file,(ulong) (endpos-bufflength+IO_SIZE),MY_SEEK_SET,
-		   MYF(0)));
+      my_seek(file,(ulong) (endpos-bufflength+IO_SIZE),MY_SEEK_SET,
+		   MYF(0));
       if ((my_write(file, buff,bufflength,MYF(MY_NABP+MY_WME))))
 	return(0);
       endpos-=bufflength; bufflength=IO_SIZE;
     }
     memset(buff, 0, IO_SIZE);			/* Null new block */
-    VOID(my_seek(file,(ulong) maxlength,MY_SEEK_SET,MYF(0)));
+    my_seek(file,(ulong) maxlength,MY_SEEK_SET,MYF(0));
     if (my_write(file,buff,bufflength,MYF(MY_NABP+MY_WME)))
 	return(0L);
     maxlength+=IO_SIZE;				/* Fix old ref */
@@ -1620,11 +1620,11 @@
   if (n_length == 1 )
   {						/* First name */
     length++;
-    VOID(strxmov((char*) buff,"/",newname,"/",NullS));
+    strxmov((char*) buff,"/",newname,"/",NullS);
   }
   else
-    VOID(strxmov((char*) buff,newname,"/",NullS)); /* purecov: inspected */
-  VOID(my_seek(file,63L+(ulong) n_length,MY_SEEK_SET,MYF(0)));
+    strxmov((char*) buff,newname,"/",NullS); /* purecov: inspected */
+  my_seek(file,63L+(ulong) n_length,MY_SEEK_SET,MYF(0));
   if (my_write(file, buff, (size_t) length+1,MYF(MY_NABP+MY_WME)) ||
       (names && my_write(file,(uchar*) (*formnames->type_names+n_length-1),
 			 names*4, MYF(MY_NABP+MY_WME))) ||
@@ -1995,8 +1995,8 @@
     {
       if (my_write(file,fill, IO_SIZE, MYF(MY_WME | MY_NABP)))
       {
-	VOID(my_close(file,MYF(0)));
-	VOID(my_delete(name,MYF(0)));
+	my_close(file,MYF(0));
+	my_delete(name,MYF(0));
 	return(-1);
       }
     }
@@ -2054,8 +2054,8 @@
 rename_file_ext(const char * from,const char * to,const char * ext)
 {
   char from_b[FN_REFLEN],to_b[FN_REFLEN];
-  VOID(strxmov(from_b,from,ext,NullS));
-  VOID(strxmov(to_b,to,ext,NullS));
+  strxmov(from_b,from,ext,NullS);
+  strxmov(to_b,to,ext,NullS);
   return (my_rename(from_b,to_b,MYF(MY_WME)));
 }
 

